# Yotpy

An easy-to-use Python wrapper for the Yotpo API. Developed to fill the gap of existing packages that didn't meet specific needs.

## Installation

Install `yotpy` using pip:

```bash
pip install yotpy
```

## Documentation

The current documentation is updated on every update to main and can be found [here](https://wlk-dev.github.io/yotpy/yotpy.html).
